==> haskell-crypton-x509-validation-1.6.14-50-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-validation
version:              1.6.14
visibility:           public
id:                   crypton-x509-validation-1.6.14-7gEKRuHl5Iy9EhA8cHy7A3
key:                  crypton-x509-validation-1.6.14-7gEKRuHl5Iy9EhA8cHy7A3
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  e604def52c11c2cb64f66e383b24b580
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.14-7gEKRuHl5Iy9EhA8cHy7A3
depends:
    asn1-encoding-0.9.6-65YxMp5s6gF6iIu44XaraU
    asn1-types-0.3.4-E7AJjgov5uJ6vs2pOB9kXU base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-15CSq8PrPPY2dmnZbUXwmg
    crypton-x509-1.7.7-GCmMeV7EeUI8CgDMCUhQM
    crypton-x509-store-1.6.11-3gsx4ijW8e225kUpulvLSh
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    hourglass-0.2.12-IvUkdQIbEA7IzH7WFALDE7
    iproute-1.7.15-CvTEctF50fpCVP30aLYfzx
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    pem-0.2.4-9kYOxfRtzqO4vjCBbq6kRF

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypton-x509-validation-1.6.14-51-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-crypton-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 crypton-x509-validation
version:              1.6.14
visibility:           public
id:                   crypton-x509-validation-1.6.14-IZzvTQXOLl496OOCwyHnet
key:                  crypton-x509-validation-1.6.14-IZzvTQXOLl496OOCwyHnet
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/kazu-yamamoto/crypton-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  cfd979091ead1e608da9c7c39d564f84
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/crypton-x509-validation-1.6.14

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-crypton-x509-validation
hs-libraries:         HScrypton-x509-validation-1.6.14-IZzvTQXOLl496OOCwyHnet
depends:
    asn1-encoding-0.9.6-5OP0Q8LgdK7BnavlpIcm0B
    asn1-types-0.3.4-3yndFOH6QHi1UcpzwUNu52 base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    crypton-1.0.4-HsWWtLvSQjKFYKNmIISx6y
    crypton-x509-1.7.7-Bys8hEW7ejs2xMP8g7qFgO
    crypton-x509-store-1.6.11-GdC0mOe0ADXL5U6jh37C6z
    data-default-0.7.1.3-EtVHsfbH5oIpJ9umzYHUz
    hourglass-0.2.12-5onhNKsXmSl4AGQbTdjwEM
    iproute-1.7.15-60NLZ4uf2hCB2Eo5ul1FMn
    memory-0.18.0-6zo36PbRecTK4fqbBnx0f5 mtl-2.3.1
    pem-0.2.4-6r7SAVDXVj1JPYYJyZrEuM

haddock-interfaces:
    /usr/share/doc/haskell-crypton-x509-validation/html/crypton-x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-crypton-x509-validation/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
